summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/securestream.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/securestream.cpp')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/securestream.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/securestream.cpp b/kopete/protocols/groupwise/libgroupwise/securestream.cpp
index 569090c0..2879d77e 100644
--- a/kopete/protocols/groupwise/libgroupwise/securestream.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/securestream.cpp
@@ -22,7 +22,7 @@
Note: SecureStream depends on the underlying security layers to signal
plain-to-encrypted results immediately (as opposed to waiting for the
event loop) so that the user cannot add/remove security layers during
- this conversion moment. QCA::TLS and QCA::SASL behave as expected,
+ this conversion moment. TQCA::TLS and TQCA::SASL behave as expected,
but future layers might not.
*/
@@ -86,7 +86,7 @@ int LayerTracker::finished(int encoded)
// SecureStream
//----------------------------------------------------------------------------
-SecureLayer::SecureLayer(QCA::TLS *t)
+SecureLayer::SecureLayer(TQCA::TLS *t)
{
type = TLS;
p.tls = t;
@@ -98,7 +98,7 @@ SecureLayer::SecureLayer(QCA::TLS *t)
connect(p.tls, TQT_SIGNAL(error(int)), TQT_SLOT(tls_error(int)));
}
-SecureLayer::SecureLayer(QCA::SASL *s)
+SecureLayer::SecureLayer(TQCA::SASL *s)
{
type = SASL;
p.sasl = s;
@@ -329,7 +329,7 @@ int SecureStream::calcPrebytes() const
return (d->pending - x);
}
-void SecureStream::startTLSClient(QCA::TLS *t, const TQByteArray &spare)
+void SecureStream::startTLSClient(TQCA::TLS *t, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveTLS())
return;
@@ -343,7 +343,7 @@ void SecureStream::startTLSClient(QCA::TLS *t, const TQByteArray &spare)
insertData(spare);
}
-void SecureStream::startTLSServer(QCA::TLS *t, const TQByteArray &spare)
+void SecureStream::startTLSServer(TQCA::TLS *t, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveTLS())
return;
@@ -357,7 +357,7 @@ void SecureStream::startTLSServer(QCA::TLS *t, const TQByteArray &spare)
insertData(spare);
}
-void SecureStream::setLayerSASL(QCA::SASL *sasl, const TQByteArray &spare)
+void SecureStream::setLayerSASL(TQCA::SASL *sasl, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveSASL())
return;
@@ -382,7 +382,7 @@ void SecureStream::startTLSClient(TLSHandler *t, const TQString &server, const T
d->layers.append(s);
d->topInProgress = true;
// unlike QCA::TLS, TLSHandler has no return value
s->p.tlsHandler->startClient(server);
insertData(spare);
@@ -382,7 +382,7 @@ void SecureStream::startTLSClient(TLSHandler *t, const TQString &server, const T
d->layers.append(s);
d->topInProgress = true;
- // unlike QCA::TLS, TLSHandler has no return value
+ // unlike TQCA::TLS, TLSHandler has no return value
s->p.tlsHandler->startClient(server);
insertData(spare);